from .whatshap import MultiqcModule

__all__ = ["MultiqcModule"]
